function [alfa, dist]=readLidar(pose, paredes, var_d)
% FEUP/MIEEC/SRAU - 2012/2013 TI2
%
% simula??o da leitura de um laser range finder
%
% par?metros de entrada:
%   pose: vetor com pose do robot (x,y,teta)
%   paredes: matrix (n linhas * 4 colunas) com coordenadas
%            das paredes, cada linha: [x0 x1 y0 y1]
%   var_d: vari?ncia das medidas de dist?ncia
%
% valores de sa?da:
%   alfa: vetor com os ?ngulos de medi??o do laser (rad)
%   dist: vetor com as dist?ncia medidas correspondentes aos ?ngulos,
%         caso n?o haja medida para um dado ?ngulo ? preenchido com -1
%
% par?metros internos:
%   ALFA_MAX: valores limite do ?ngulo (em graus)
%   DELTA_ALFA: passo do ?ngulo (em graus)
%   CONDMAX: valor limite para o mau condicionamento da matrix do sist
%            de eq lineares a resolver para determinar cada dist?ncia
%   TOL: fra??o max do comprimento de cada parede para dete??o
%        interse??es
%
global laserSensorSettings

ALFA_MAX = laserSensorSettings.maxBearing;
DELTA_ALFA = laserSensorSettings.deltaBearing;
MAX_DIST = laserSensorSettings.maxRange;
CONDMAX = 1e7;
TOL = 0.001;

alfa = pi/180*(-ALFA_MAX:DELTA_ALFA:ALFA_MAX);
dist = -1 + 0*alfa;
if nargin<3
    var_d = 0;
end;

for jj=1:length(alfa)
    for kk=1:size(paredes,1)
        A = [paredes(kk,2)-paredes(kk,1) -cos(pose(3)+alfa(jj));...
             paredes(kk,4)-paredes(kk,3) -sin(pose(3)+alfa(jj))];
        if cond(A)>CONDMAX continue; end
        B = [pose(1)-paredes(kk,1); pose(2)-paredes(kk,3)];
        SOL = A\B + [0; sqrt(var_d)*randn];
        if SOL(2)<0 || SOL(1)>1+TOL || SOL(1)<-TOL continue; end
        if dist(jj)<0 || SOL(2)<dist(jj)
            dist(jj) = SOL(2);
            if(dist(jj) >MAX_DIST)
                dist(jj) =-1;
            end
        end
    end
end



        
